@@ -138,11 +138,11 @@ return [
         'en_GU' => 'Englesch (Guam)',
         'en_GY' => 'Englesch (Guyana)',
         'en_HK' => 'Englesch (Spezialverwaltungszon Hong Kong)',
+        'en_ID' => 'Englesch (Indonesien)',
         'en_IE' => 'Englesch (Irland)',
         'en_IL' => 'Englesch (Israel)',
         'en_IM' => 'Englesch (Isle of Man)',
         'en_IN' => 'Englesch (Indien)',
-        'en_IO' => 'Englesch (Britescht Territorium am Indeschen Ozean)',
         'en_JE' => 'Englesch (Jersey)',
         'en_JM' => 'Englesch (Jamaika)',
         'en_KE' => 'Englesch (Kenia)',
@@ -344,6 +344,8 @@ return [
         'ia_001' => 'Interlingua (Welt)',
         'id' => 'Indonesesch',
         'id_ID' => 'Indonesesch (Indonesien)',
+        'ie' => 'Interlingue',
+        'ie_EE' => 'Interlingue (Estland)',
         'ig' => 'Igbo-Sprooch',
         'ig_NG' => 'Igbo-Sprooch (Nigeria)',
         'ii' => 'Sichuan Yi',
@@ -372,6 +374,7 @@ return [
         'kn' => 'Kannada',
         'kn_IN' => 'Kannada (Indien)',
         'ko' => 'Koreanesch',
+        'ko_CN' => 'Koreanesch (China)',
         'ko_KP' => 'Koreanesch (Nordkorea)',
         'ko_KR' => 'Koreanesch (Südkorea)',
         'ks' => 'Kaschmiresch',
@@ -444,6 +447,9 @@ return [
         'nn_NO' => 'Norwegesch Nynorsk (Norwegen)',
         'no' => 'Norwegesch',
         'no_NO' => 'Norwegesch (Norwegen)',
+        'oc' => 'Okzitanesch',
+        'oc_ES' => 'Okzitanesch (Spanien)',
+        'oc_FR' => 'Okzitanesch (Frankräich)',
         'om' => 'Oromo',
         'om_ET' => 'Oromo (Ethiopien)',
         'om_KE' => 'Oromo (Kenia)',
@@ -605,10 +611,12 @@ return [
         'xh' => 'Xhosa',
         'xh_ZA' => 'Xhosa (Südafrika)',
         'yi' => 'Jiddesch',
-        'yi_001' => 'Jiddesch (Welt)',
+        'yi_UA' => 'Jiddesch (Ukrain)',
         'yo' => 'Yoruba',
         'yo_BJ' => 'Yoruba (Benin)',
         'yo_NG' => 'Yoruba (Nigeria)',
+        'za' => 'Zhuang',
+        'za_CN' => 'Zhuang (China)',
         'zh' => 'Chinesesch',
         'zh_CN' => 'Chinesesch (China)',
         'zh_HK' => 'Chinesesch (Spezialverwaltungszon Hong Kong)',
