@@ -4,61 +4,61 @@ return [
     'Names' => [
         'Africa/Abidjan' => 'hora medie de Greenwich (Abidjan)',
         'Africa/Accra' => 'hora medie de Greenwich (Accra)',
-        'Africa/Addis_Ababa' => 'hora de Ethiopia (Addis Ababa)',
+        'Africa/Addis_Ababa' => 'hora de Africa del Est (Addis Ababa)',
         'Africa/Algiers' => 'hora de Europa central (Algiers)',
-        'Africa/Asmera' => 'hora de Eritrea (Asmara)',
+        'Africa/Asmera' => 'hora de Africa del Est (Asmara)',
         'Africa/Bamako' => 'hora medie de Greenwich (Bamako)',
-        'Africa/Bangui' => 'hora de Republica African Central (Bangui)',
+        'Africa/Bangui' => 'hora de Africa del West (Bangui)',
         'Africa/Banjul' => 'hora medie de Greenwich (Banjul)',
         'Africa/Bissau' => 'hora medie de Greenwich (Bissau)',
-        'Africa/Blantyre' => 'hora de Malawi (Blantyre)',
-        'Africa/Brazzaville' => 'hora de Congo - Brazzaville (Brazzaville)',
-        'Africa/Bujumbura' => 'hora de Burundi (Bujumbura)',
+        'Africa/Blantyre' => 'hora de Africa Central (Blantyre)',
+        'Africa/Brazzaville' => 'hora de Africa del West (Brazzaville)',
+        'Africa/Bujumbura' => 'hora de Africa Central (Bujumbura)',
         'Africa/Cairo' => 'hora de Europa oriental (Cairo)',
         'Africa/Casablanca' => 'hora de Europa occidental (Casablanca)',
         'Africa/Ceuta' => 'hora de Europa central (Ceuta)',
         'Africa/Conakry' => 'hora medie de Greenwich (Conakry)',
         'Africa/Dakar' => 'hora medie de Greenwich (Dakar)',
-        'Africa/Dar_es_Salaam' => 'hora de Tanzania (Dar es Salaam)',
-        'Africa/Djibouti' => 'hora de Djibuti (Djibuti)',
-        'Africa/Douala' => 'hora de Camerun (Douala)',
+        'Africa/Dar_es_Salaam' => 'hora de Africa del Est (Dar es Salaam)',
+        'Africa/Djibouti' => 'hora de Africa del Est (Djibuti)',
+        'Africa/Douala' => 'hora de Africa del West (Douala)',
         'Africa/El_Aaiun' => 'hora de Europa occidental (El Aaiun)',
         'Africa/Freetown' => 'hora medie de Greenwich (Freetown)',
-        'Africa/Gaborone' => 'hora de Botswana (Gaborone)',
-        'Africa/Harare' => 'hora de Zimbabwe (Harare)',
-        'Africa/Johannesburg' => 'hora de Africa del Sud (Johannesburg)',
-        'Africa/Juba' => 'hora de Sudan del Sud (Juba)',
-        'Africa/Kampala' => 'hora de Uganda (Kampala)',
-        'Africa/Khartoum' => 'hora de Sudan (Khartoum)',
-        'Africa/Kigali' => 'hora de Ruanda (Kigali)',
-        'Africa/Kinshasa' => 'hora de Congo - Kinshasa (Kinshasa)',
-        'Africa/Lagos' => 'hora de Nigeria (Lagos)',
-        'Africa/Libreville' => 'hora de Gabon (Libreville)',
+        'Africa/Gaborone' => 'hora de Africa Central (Gaborone)',
+        'Africa/Harare' => 'hora de Africa Central (Harare)',
+        'Africa/Johannesburg' => 'hora standard de Africa del Sud (Johannesburg)',
+        'Africa/Juba' => 'hora de Africa Central (Juba)',
+        'Africa/Kampala' => 'hora de Africa del Est (Kampala)',
+        'Africa/Khartoum' => 'hora de Africa Central (Khartoum)',
+        'Africa/Kigali' => 'hora de Africa Central (Kigali)',
+        'Africa/Kinshasa' => 'hora de Africa del West (Kinshasa)',
+        'Africa/Lagos' => 'hora de Africa del West (Lagos)',
+        'Africa/Libreville' => 'hora de Africa del West (Libreville)',
         'Africa/Lome' => 'hora medie de Greenwich (Lome)',
-        'Africa/Luanda' => 'hora de Angola (Luanda)',
-        'Africa/Lubumbashi' => 'hora de Congo - Kinshasa (Lubumbashi)',
-        'Africa/Lusaka' => 'hora de Zambia (Lusaka)',
-        'Africa/Malabo' => 'hora de Guinea equatorial (Malabo)',
-        'Africa/Maputo' => 'hora de Mozambique (Maputo)',
-        'Africa/Maseru' => 'hora de Lesotho (Maseru)',
-        'Africa/Mbabane' => 'hora de Eswatini (Mbabane)',
-        'Africa/Mogadishu' => 'hora de Somalia (Mogadishu)',
+        'Africa/Luanda' => 'hora de Africa del West (Luanda)',
+        'Africa/Lubumbashi' => 'hora de Africa Central (Lubumbashi)',
+        'Africa/Lusaka' => 'hora de Africa Central (Lusaka)',
+        'Africa/Malabo' => 'hora de Africa del West (Malabo)',
+        'Africa/Maputo' => 'hora de Africa Central (Maputo)',
+        'Africa/Maseru' => 'hora standard de Africa del Sud (Maseru)',
+        'Africa/Mbabane' => 'hora standard de Africa del Sud (Mbabane)',
+        'Africa/Mogadishu' => 'hora de Africa del Est (Mogadishu)',
         'Africa/Monrovia' => 'hora medie de Greenwich (Monrovia)',
-        'Africa/Nairobi' => 'hora de Kenya (Nairobi)',
-        'Africa/Ndjamena' => 'hora de Tchad (Ndjamena)',
-        'Africa/Niamey' => 'hora de Niger (Niamey)',
+        'Africa/Nairobi' => 'hora de Africa del Est (Nairobi)',
+        'Africa/Ndjamena' => 'hora de Africa del West (Ndjamena)',
+        'Africa/Niamey' => 'hora de Africa del West (Niamey)',
         'Africa/Nouakchott' => 'hora medie de Greenwich (Nouakchott)',
         'Africa/Ouagadougou' => 'hora medie de Greenwich (Ouagadougou)',
-        'Africa/Porto-Novo' => 'hora de Benin (Porto-Novo)',
-        'Africa/Sao_Tome' => 'hora medie de Greenwich (Sao Tome)',
+        'Africa/Porto-Novo' => 'hora de Africa del West (Porto-Novo)',
+        'Africa/Sao_Tome' => 'hora medie de Greenwich (São Tomé)',
         'Africa/Tripoli' => 'hora de Europa oriental (Tripoli)',
         'Africa/Tunis' => 'hora de Europa central (Tunis)',
-        'Africa/Windhoek' => 'hora de Namibia (Windhoek)',
+        'Africa/Windhoek' => 'hora de Africa Central (Windhoek)',
         'America/Adak' => 'hora de Hawaii-Aleutianas (Adak)',
         'America/Anchorage' => 'hora de Alaska (Anchorage)',
         'America/Anguilla' => 'hora atlantic (Anguilla)',
         'America/Antigua' => 'hora atlantic (Antigua)',
-        'America/Araguaina' => 'hora de Brasil (Araguaina)',
+        'America/Araguaina' => 'hora de Brasilia (Araguaina)',
         'America/Argentina/La_Rioja' => 'hora de Argentina (La Rioja)',
         'America/Argentina/Rio_Gallegos' => 'hora de Argentina (Rio Gallegos)',
         'America/Argentina/Salta' => 'hora de Argentina (Salta)',
@@ -67,23 +67,23 @@ return [
         'America/Argentina/Tucuman' => 'hora de Argentina (Tucuman)',
         'America/Argentina/Ushuaia' => 'hora de Argentina (Ushuaia)',
         'America/Aruba' => 'hora atlantic (Aruba)',
-        'America/Asuncion' => 'hora de Paraguay (Asuncion)',
-        'America/Bahia' => 'hora de Brasil (Bahia)',
+        'America/Asuncion' => 'hora de Paraguay (Asunción)',
+        'America/Bahia' => 'hora de Brasilia (Bahia)',
         'America/Bahia_Banderas' => 'hora central (Bahia de Banderas)',
         'America/Barbados' => 'hora atlantic (Barbados)',
-        'America/Belem' => 'hora de Brasil (Belem)',
+        'America/Belem' => 'hora de Brasilia (Belem)',
         'America/Belize' => 'hora central (Belize)',
         'America/Blanc-Sablon' => 'hora atlantic (Blanc-Sablon)',
-        'America/Boa_Vista' => 'hora de Brasil (Boa Vista)',
+        'America/Boa_Vista' => 'hora de Amazonia (Boa Vista)',
         'America/Bogota' => 'hora de Colombia (Bogota)',
         'America/Boise' => 'hora del montanias (Boise)',
         'America/Buenos_Aires' => 'hora de Argentina (Buenos Aires)',
         'America/Cambridge_Bay' => 'hora del montanias (Cambridge Bay)',
-        'America/Campo_Grande' => 'hora de Brasil (Campo Grande)',
+        'America/Campo_Grande' => 'hora de Amazonia (Campo Grande)',
         'America/Cancun' => 'hora del est (Cancun)',
         'America/Caracas' => 'hora de Venezuela (Caracas)',
         'America/Catamarca' => 'hora de Argentina (Catamarca)',
-        'America/Cayenne' => 'hora de Guyana francese (Cayenne)',
+        'America/Cayenne' => 'hora de Guiana Francese (Cayenne)',
         'America/Cayman' => 'hora del est (Caiman)',
         'America/Chicago' => 'hora central (Chicago)',
         'America/Chihuahua' => 'hora central (Chihuahua)',
@@ -92,10 +92,10 @@ return [
         'America/Cordoba' => 'hora de Argentina (Cordoba)',
         'America/Costa_Rica' => 'hora central (Costa Rica)',
         'America/Creston' => 'hora del montanias (Creston)',
-        'America/Cuiaba' => 'hora de Brasil (Cuiaba)',
+        'America/Cuiaba' => 'hora de Amazonia (Cuiaba)',
         'America/Curacao' => 'hora atlantic (Curaçao)',
         'America/Danmarkshavn' => 'hora medie de Greenwich (Danmarkshavn)',
-        'America/Dawson' => 'hora de Canada (Dawson)',
+        'America/Dawson' => 'hora de Yukon (Dawson)',
         'America/Dawson_Creek' => 'hora del montanias (Dawson Creek)',
         'America/Denver' => 'hora del montanias (Denver)',
         'America/Detroit' => 'hora del est (Detroit)',
@@ -104,16 +104,16 @@ return [
         'America/Eirunepe' => 'hora de Brasil (Eirunepe)',
         'America/El_Salvador' => 'hora central (El Salvador)',
         'America/Fort_Nelson' => 'hora del montanias (Fort Nelson)',
-        'America/Fortaleza' => 'hora de Brasil (Fortaleza)',
+        'America/Fortaleza' => 'hora de Brasilia (Fortaleza)',
         'America/Glace_Bay' => 'hora atlantic (Glace Bay)',
-        'America/Godthab' => 'hora de Groenlandia occidental (Nuuk)',
+        'America/Godthab' => 'hora de Groenlandia (Nuuk)',
         'America/Goose_Bay' => 'hora atlantic (Goose Bay)',
         'America/Grand_Turk' => 'hora del est (Grand Turk)',
         'America/Grenada' => 'hora atlantic (Grenada)',
         'America/Guadeloupe' => 'hora atlantic (Guadeloupe)',
         'America/Guatemala' => 'hora central (Guatemala)',
         'America/Guayaquil' => 'hora de Ecuador (Guayaquil)',
-        'America/Guyana' => 'hora de Guyana (Guyana)',
+        'America/Guyana' => 'hora de Guyana',
         'America/Halifax' => 'hora atlantic (Halifax)',
         'America/Havana' => 'hora de Cuba (Havana)',
         'America/Hermosillo' => 'hora del Pacifico mexican (Hermosillo)',
@@ -137,9 +137,9 @@ return [
         'America/Los_Angeles' => 'hora pacific (Los Angeles)',
         'America/Louisville' => 'hora del est (Louisville)',
         'America/Lower_Princes' => 'hora atlantic (Lower Prince’s Quarter)',
-        'America/Maceio' => 'hora de Brasil (Maceio)',
+        'America/Maceio' => 'hora de Brasilia (Maceio)',
         'America/Managua' => 'hora central (Managua)',
-        'America/Manaus' => 'hora de Brasil (Manaus)',
+        'America/Manaus' => 'hora de Amazonia (Manaus)',
         'America/Marigot' => 'hora atlantic (Marigot)',
         'America/Martinique' => 'hora atlantic (Martinica)',
         'America/Matamoros' => 'hora central (Matamoros)',
@@ -156,34 +156,30 @@ return [
         'America/Montserrat' => 'hora atlantic (Montserrat)',
         'America/Nassau' => 'hora del est (Nassau)',
         'America/New_York' => 'hora del est (Nove York)',
-        'America/Nipigon' => 'hora del est (Nipigon)',
         'America/Nome' => 'hora de Alaska (Nome)',
-        'America/Noronha' => 'hora de Brasil (Noronha)',
+        'America/Noronha' => 'hora de Fernando de Noronha',
         'America/North_Dakota/Beulah' => 'hora central (Beulah, Dakota del Nord)',
         'America/North_Dakota/Center' => 'hora central (Center, Dakota del Nord)',
         'America/North_Dakota/New_Salem' => 'hora central (New Salem, Dakota del Nord)',
         'America/Ojinaga' => 'hora central (Ojinaga)',
         'America/Panama' => 'hora del est (Panama)',
-        'America/Pangnirtung' => 'hora del est (Pangnirtung)',
         'America/Paramaribo' => 'hora de Suriname (Paramaribo)',
         'America/Phoenix' => 'hora del montanias (Phoenix)',
         'America/Port-au-Prince' => 'hora del est (Port-au-Prince)',
         'America/Port_of_Spain' => 'hora atlantic (Port of Spain)',
-        'America/Porto_Velho' => 'hora de Brasil (Porto Velho)',
+        'America/Porto_Velho' => 'hora de Amazonia (Porto Velho)',
         'America/Puerto_Rico' => 'hora atlantic (Porto Rico)',
         'America/Punta_Arenas' => 'hora de Chile (Punta Arenas)',
-        'America/Rainy_River' => 'hora central (Rainy River)',
         'America/Rankin_Inlet' => 'hora central (Rankin Inlet)',
-        'America/Recife' => 'hora de Brasil (Recife)',
+        'America/Recife' => 'hora de Brasilia (Recife)',
         'America/Regina' => 'hora central (Regina)',
         'America/Resolute' => 'hora central (Resolute)',
         'America/Rio_Branco' => 'hora de Brasil (Rio Branco)',
-        'America/Santa_Isabel' => 'hora del nordwest de Mexico (Santa Isabel)',
-        'America/Santarem' => 'hora de Brasil (Santarem)',
+        'America/Santarem' => 'hora de Brasilia (Santarem)',
         'America/Santiago' => 'hora de Chile (Santiago)',
         'America/Santo_Domingo' => 'hora atlantic (Santo Domingo)',
-        'America/Sao_Paulo' => 'hora de Brasil (Sao Paulo)',
-        'America/Scoresbysund' => 'hora de Groenlandia oriental (Ittoqqortoormiit)',
+        'America/Sao_Paulo' => 'hora de Brasilia (Sao Paulo)',
+        'America/Scoresbysund' => 'hora de Groenlandia (Ittoqqortoormiit)',
         'America/Sitka' => 'hora de Alaska (Sitka)',
         'America/St_Barthelemy' => 'hora atlantic (Sancte Bartholomeo)',
         'America/St_Johns' => 'hora de Terranova (Sancte Johannes de Terranova)',
@@ -194,60 +190,58 @@ return [
         'America/Swift_Current' => 'hora central (Swift Current)',
         'America/Tegucigalpa' => 'hora central (Tegucigalpa)',
         'America/Thule' => 'hora atlantic (Thule)',
-        'America/Thunder_Bay' => 'hora del est (Thunder Bay)',
         'America/Tijuana' => 'hora pacific (Tijuana)',
         'America/Toronto' => 'hora del est (Toronto)',
         'America/Tortola' => 'hora atlantic (Tortola)',
         'America/Vancouver' => 'hora pacific (Vancouver)',
-        'America/Whitehorse' => 'hora de Canada (Whitehorse)',
+        'America/Whitehorse' => 'hora de Yukon (Whitehorse)',
         'America/Winnipeg' => 'hora central (Winnipeg)',
         'America/Yakutat' => 'hora de Alaska (Yakutat)',
-        'America/Yellowknife' => 'hora del montanias (Yellowknife)',
-        'Antarctica/Casey' => 'hora de Antarctica (Casey)',
-        'Antarctica/Davis' => 'hora de Antarctica (Davis)',
-        'Antarctica/DumontDUrville' => 'hora de Antarctica (Dumont d’Urville)',
-        'Antarctica/Macquarie' => 'hora de Australia (Macquarie)',
-        'Antarctica/Mawson' => 'hora de Antarctica (Mawson)',
-        'Antarctica/McMurdo' => 'hora de Antarctica (McMurdo)',
-        'Antarctica/Palmer' => 'hora de Antarctica (Palmer)',
-        'Antarctica/Rothera' => 'hora de Antarctica (Rothera)',
-        'Antarctica/Syowa' => 'hora de Antarctica (Syowa)',
+        'Antarctica/Casey' => 'hora de Australia occidental (Casey)',
+        'Antarctica/Davis' => 'hora de Davis',
+        'Antarctica/DumontDUrville' => 'hora de Dumont-d’Urville',
+        'Antarctica/Macquarie' => 'hora de Australia oriental (Macquarie)',
+        'Antarctica/Mawson' => 'hora de Mawson',
+        'Antarctica/McMurdo' => 'hora de Nove Zelanda (McMurdo)',
+        'Antarctica/Palmer' => 'hora de Chile (Palmer)',
+        'Antarctica/Rothera' => 'hora de Rothera',
+        'Antarctica/Syowa' => 'hora de Syowa',
         'Antarctica/Troll' => 'hora medie de Greenwich (Troll)',
-        'Antarctica/Vostok' => 'hora de Antarctica (Vostok)',
+        'Antarctica/Vostok' => 'hora de Vostok',
         'Arctic/Longyearbyen' => 'hora de Europa central (Longyearbyen)',
-        'Asia/Aden' => 'hora de Yemen (Aden)',
-        'Asia/Almaty' => 'hora de Kazakhstan (Almaty)',
+        'Asia/Aden' => 'hora arabe (Aden)',
+        'Asia/Almaty' => 'hora de Kazakhstan del West (Almaty)',
         'Asia/Amman' => 'hora de Europa oriental (Amman)',
         'Asia/Anadyr' => 'hora de Russia (Anadyr)',
-        'Asia/Aqtau' => 'hora de Kazakhstan (Aqtau)',
-        'Asia/Aqtobe' => 'hora de Kazakhstan (Aqtobe)',
+        'Asia/Aqtau' => 'hora de Kazakhstan del West (Aqtau)',
+        'Asia/Aqtobe' => 'hora de Kazakhstan del West (Aqtobe)',
         'Asia/Ashgabat' => 'hora de Turkmenistan (Ashgabat)',
-        'Asia/Atyrau' => 'hora de Kazakhstan (Atyrau)',
-        'Asia/Baghdad' => 'hora de Irak (Baghdad)',
-        'Asia/Bahrain' => 'hora de Bahrain (Bahrain)',
-        'Asia/Baku' => 'hora de Azerbaidzhan (Baku)',
-        'Asia/Bangkok' => 'hora de Thailandia (Bangkok)',
+        'Asia/Atyrau' => 'hora de Kazakhstan del West (Atyrau)',
+        'Asia/Baghdad' => 'hora arabe (Baghdad)',
+        'Asia/Bahrain' => 'hora arabe (Bahrein)',
+        'Asia/Baku' => 'hora de Azerbeidzhan (Baku)',
+        'Asia/Bangkok' => 'hora de Indochina (Bangkok)',
         'Asia/Barnaul' => 'hora de Russia (Barnaul)',
         'Asia/Beirut' => 'hora de Europa oriental (Beirut)',
         'Asia/Bishkek' => 'hora de Kirghizistan (Bishkek)',
-        'Asia/Brunei' => 'hora de Brunei (Brunei)',
-        'Asia/Calcutta' => 'hora de India (Kolkata)',
+        'Asia/Brunei' => 'hora de Brunei Darussalam',
+        'Asia/Calcutta' => 'hora standard de India (Calcutta)',
         'Asia/Chita' => 'hora de Yakutsk (Chita)',
-        'Asia/Choibalsan' => 'hora de Mongolia (Choibalsan)',
-        'Asia/Colombo' => 'hora de Sri Lanka (Colombo)',
-        'Asia/Damascus' => 'hora de Europa oriental (Damascus)',
+        'Asia/Choibalsan' => 'hora de Ulan Bator (Choibalsan)',
+        'Asia/Colombo' => 'hora standard de India (Colombo)',
+        'Asia/Damascus' => 'hora de Europa oriental (Damasco)',
         'Asia/Dhaka' => 'hora de Bangladesh (Dhaka)',
         'Asia/Dili' => 'hora de Timor del Est (Dili)',
-        'Asia/Dubai' => 'hora de Emiratos Arabe Unite (Dubai)',
-        'Asia/Dushanbe' => 'hora de Tadzhikistan (Dushanbe)',
+        'Asia/Dubai' => 'hora standard del Golfo (Dubai)',
+        'Asia/Dushanbe' => 'hora de Tajikistan (Dushanbe)',
         'Asia/Famagusta' => 'hora de Europa oriental (Famagusta)',
         'Asia/Gaza' => 'hora de Europa oriental (Gaza)',
         'Asia/Hebron' => 'hora de Europa oriental (Hebron)',
-        'Asia/Hong_Kong' => 'hora de Hongkong, R.A.S. de China (Hongkong)',
-        'Asia/Hovd' => 'hora de Mongolia (Hovd)',
+        'Asia/Hong_Kong' => 'hora de Hongkong',
+        'Asia/Hovd' => 'hora de Hovd',
         'Asia/Irkutsk' => 'hora de Irkutsk',
-        'Asia/Jakarta' => 'hora de Indonesia (Jakarta)',
-        'Asia/Jayapura' => 'hora de Indonesia (Jayapura)',
+        'Asia/Jakarta' => 'hora de Indonesia del West (Jakarta)',
+        'Asia/Jayapura' => 'hora de Indonesia del Est (Jayapura)',
         'Asia/Jerusalem' => 'hora de Israel (Jerusalem)',
         'Asia/Kabul' => 'hora de Afghanistan (Kabul)',
         'Asia/Kamchatka' => 'hora de Russia (Kamchatka)',
@@ -257,43 +251,43 @@ return [
         'Asia/Krasnoyarsk' => 'hora de Krasnoyarsk',
         'Asia/Kuala_Lumpur' => 'hora de Malaysia (Kuala Lumpur)',
         'Asia/Kuching' => 'hora de Malaysia (Kuching)',
-        'Asia/Kuwait' => 'hora de Kuwait (Kuwait)',
-        'Asia/Macau' => 'hora de Macao, R.A.S. de China (Macao)',
+        'Asia/Kuwait' => 'hora arabe (Kuwait)',
+        'Asia/Macau' => 'hora de China (Macao)',
         'Asia/Magadan' => 'hora de Magadan',
-        'Asia/Makassar' => 'hora de Indonesia (Makassar)',
-        'Asia/Manila' => 'hora de Philippinas (Manila)',
-        'Asia/Muscat' => 'hora de Oman (Muscat)',
+        'Asia/Makassar' => 'hora de Indonesia Central (Makassar)',
+        'Asia/Manila' => 'hora del Philippinas (Manila)',
+        'Asia/Muscat' => 'hora standard del Golfo (Muscat)',
         'Asia/Nicosia' => 'hora de Europa oriental (Nicosia)',
         'Asia/Novokuznetsk' => 'hora de Krasnoyarsk (Novokuznetsk)',
         'Asia/Novosibirsk' => 'hora de Novosibirsk',
         'Asia/Omsk' => 'hora de Omsk',
-        'Asia/Oral' => 'hora de Kazakhstan (Oral)',
-        'Asia/Phnom_Penh' => 'hora de Cambodgia (Phnom Penh)',
-        'Asia/Pontianak' => 'hora de Indonesia (Pontianak)',
-        'Asia/Pyongyang' => 'hora de Corea del Nord (Pyongyang)',
-        'Asia/Qatar' => 'hora de Qatar (Qatar)',
-        'Asia/Qostanay' => 'hora de Kazakhstan (Qostanay)',
-        'Asia/Qyzylorda' => 'hora de Kazakhstan (Qyzylorda)',
-        'Asia/Rangoon' => 'hora de Myanmar (Birmania) (Yangon)',
-        'Asia/Riyadh' => 'hora de Arabia Saudita (Riyadh)',
-        'Asia/Saigon' => 'hora de Vietnam (Ho Chi Minh)',
+        'Asia/Oral' => 'hora de Kazakhstan del West (Oral)',
+        'Asia/Phnom_Penh' => 'hora de Indochina (Phnom Penh)',
+        'Asia/Pontianak' => 'hora de Indonesia del West (Pontianak)',
+        'Asia/Pyongyang' => 'hora de Corea (Pyongyang)',
+        'Asia/Qatar' => 'hora arabe (Qatar)',
+        'Asia/Qostanay' => 'hora de Kazakhstan del West (Qostanay)',
+        'Asia/Qyzylorda' => 'hora de Kazakhstan del West (Qyzylorda)',
+        'Asia/Rangoon' => 'hora de Myanmar (Yangon)',
+        'Asia/Riyadh' => 'hora arabe (Riyadh)',
+        'Asia/Saigon' => 'hora de Indochina (Ho Chi Minh)',
         'Asia/Sakhalin' => 'hora de Sachalin',
         'Asia/Samarkand' => 'hora de Uzbekistan (Samarkand)',
-        'Asia/Seoul' => 'hora de Corea del Sud (Seoul)',
+        'Asia/Seoul' => 'hora de Corea (Seoul)',
         'Asia/Shanghai' => 'hora de China (Shanghai)',
-        'Asia/Singapore' => 'hora de Singapur (Singapore)',
+        'Asia/Singapore' => 'hora standard de Singapore',
         'Asia/Srednekolymsk' => 'hora de Magadan (Srednekolymsk)',
-        'Asia/Taipei' => 'hora de Taiwan (Taipei)',
+        'Asia/Taipei' => 'hora de Taipei',
         'Asia/Tashkent' => 'hora de Uzbekistan (Tashkent)',
         'Asia/Tbilisi' => 'hora de Georgia (Tbilisi)',
         'Asia/Tehran' => 'hora de Iran (Tehran)',
         'Asia/Thimphu' => 'hora de Bhutan (Thimphu)',
         'Asia/Tokyo' => 'hora de Japon (Tokyo)',
         'Asia/Tomsk' => 'hora de Russia (Tomsk)',
-        'Asia/Ulaanbaatar' => 'hora de Mongolia (Ulaanbaatar)',
+        'Asia/Ulaanbaatar' => 'hora de Ulan Bator',
         'Asia/Urumqi' => 'hora de China (Urumqi)',
         'Asia/Ust-Nera' => 'hora de Vladivostok (Ust-Nera)',
-        'Asia/Vientiane' => 'hora de Laos (Vientiane)',
+        'Asia/Vientiane' => 'hora de Indochina (Vientiane)',
         'Asia/Vladivostok' => 'hora de Vladivostok',
         'Asia/Yakutsk' => 'hora de Yakutsk',
         'Asia/Yekaterinburg' => 'hora de Ekaterinburg',
@@ -301,25 +295,24 @@ return [
         'Atlantic/Azores' => 'hora del Azores',
         'Atlantic/Bermuda' => 'hora atlantic (Bermuda)',
         'Atlantic/Canary' => 'hora de Europa occidental (Canarias)',
-        'Atlantic/Cape_Verde' => 'hora de Capo Verde (Capo Verde)',
+        'Atlantic/Cape_Verde' => 'hora de Capo Verde',
         'Atlantic/Faeroe' => 'hora de Europa occidental (Feroe)',
         'Atlantic/Madeira' => 'hora de Europa occidental (Madeira)',
         'Atlantic/Reykjavik' => 'hora medie de Greenwich (Reykjavik)',
-        'Atlantic/South_Georgia' => 'hora de Georgia del Sud e Insulas Sandwich Austral (South Georgia)',
+        'Atlantic/South_Georgia' => 'hora de Georgia del Sud (South Georgia)',
         'Atlantic/St_Helena' => 'hora medie de Greenwich (St. Helena)',
-        'Atlantic/Stanley' => 'hora de Insulas Falkland (Stanley)',
-        'Australia/Adelaide' => 'hora de Australia (Adelaide)',
-        'Australia/Brisbane' => 'hora de Australia (Brisbane)',
-        'Australia/Broken_Hill' => 'hora de Australia (Broken Hill)',
-        'Australia/Currie' => 'hora de Australia (Currie)',
-        'Australia/Darwin' => 'hora de Australia (Darwin)',
-        'Australia/Eucla' => 'hora de Australia (Eucla)',
-        'Australia/Hobart' => 'hora de Australia (Hobart)',
-        'Australia/Lindeman' => 'hora de Australia (Lindeman)',
-        'Australia/Lord_Howe' => 'hora de Australia (Lord Howe)',
-        'Australia/Melbourne' => 'hora de Australia (Melbourne)',
-        'Australia/Perth' => 'hora de Australia (Perth)',
-        'Australia/Sydney' => 'hora de Australia (Sydney)',
+        'Atlantic/Stanley' => 'hora del Insulas Falkland (Stanley)',
+        'Australia/Adelaide' => 'hora de Australia central (Adelaide)',
+        'Australia/Brisbane' => 'hora de Australia oriental (Brisbane)',
+        'Australia/Broken_Hill' => 'hora de Australia central (Broken Hill)',
+        'Australia/Darwin' => 'hora de Australia central (Darwin)',
+        'Australia/Eucla' => 'hora de Australia centro-occidental (Eucla)',
+        'Australia/Hobart' => 'hora de Australia oriental (Hobart)',
+        'Australia/Lindeman' => 'hora de Australia oriental (Lindeman)',
+        'Australia/Lord_Howe' => 'hora de Lord Howe',
+        'Australia/Melbourne' => 'hora de Australia oriental (Melbourne)',
+        'Australia/Perth' => 'hora de Australia occidental (Perth)',
+        'Australia/Sydney' => 'hora de Australia oriental (Sydney)',
         'CST6CDT' => 'hora central',
         'EST5EDT' => 'hora del est',
         'Etc/GMT' => 'hora medie de Greenwich',
@@ -374,7 +367,6 @@ return [
         'Europe/Tallinn' => 'hora de Europa oriental (Tallinn)',
         'Europe/Tirane' => 'hora de Europa central (Tirana)',
         'Europe/Ulyanovsk' => 'hora de Moscova (Ulyanovsk)',
-        'Europe/Uzhgorod' => 'hora de Europa oriental (Uzhgorod)',
         'Europe/Vaduz' => 'hora de Europa central (Vaduz)',
         'Europe/Vatican' => 'hora de Europa central (Vaticano)',
         'Europe/Vienna' => 'hora de Europa central (Vienna)',
@@ -382,61 +374,58 @@ return [
         'Europe/Volgograd' => 'hora de Volgograd',
         'Europe/Warsaw' => 'hora de Europa central (Varsovia)',
         'Europe/Zagreb' => 'hora de Europa central (Zagreb)',
-        'Europe/Zaporozhye' => 'hora de Europa oriental (Zaporozhye)',
         'Europe/Zurich' => 'hora de Europa central (Zurich)',
-        'Indian/Antananarivo' => 'hora de Madagascar (Antananarivo)',
-        'Indian/Chagos' => 'hora de Territorio oceanic britanno-indian (Chagos)',
-        'Indian/Christmas' => 'hora de Insula de Natal (Christmas)',
-        'Indian/Cocos' => 'hora de Insulas Cocos (Keeling) (Cocos)',
-        'Indian/Comoro' => 'hora de Comoros (Comoro)',
-        'Indian/Kerguelen' => 'hora de Territorios meridional francese (Kerguelen)',
-        'Indian/Mahe' => 'hora de Seychelles (Mahe)',
-        'Indian/Maldives' => 'hora de Maldivas (Maldivas)',
-        'Indian/Mauritius' => 'hora de Mauritio (Mauritio)',
-        'Indian/Mayotte' => 'hora de Mayotte (Mayotta)',
-        'Indian/Reunion' => 'hora de Reunion (Reunion)',
+        'Indian/Antananarivo' => 'hora de Africa del Est (Antananarivo)',
+        'Indian/Chagos' => 'hora del Oceano Indian (Chagos)',
+        'Indian/Christmas' => 'hora del Insula de Natal',
+        'Indian/Cocos' => 'hora del Insulas Cocos',
+        'Indian/Comoro' => 'hora de Africa del Est (Comoro)',
+        'Indian/Kerguelen' => 'hora francese meridional e antarctic (Kerguelen)',
+        'Indian/Mahe' => 'hora del Seychelles (Mahe)',
+        'Indian/Maldives' => 'hora del Maldivas',
+        'Indian/Mauritius' => 'hora de Mauritio',
+        'Indian/Mayotte' => 'hora de Africa del Est (Mayotta)',
+        'Indian/Reunion' => 'hora de Réunion',
         'MST7MDT' => 'hora del montanias',
         'PST8PDT' => 'hora pacific',
-        'Pacific/Apia' => 'hora de Samoa (Apia)',
+        'Pacific/Apia' => 'hora de Apia',
         'Pacific/Auckland' => 'hora de Nove Zelanda (Auckland)',
         'Pacific/Bougainville' => 'hora de Papua Nove Guinea (Bougainville)',
-        'Pacific/Chatham' => 'hora de Nove Zelanda (Chatham)',
-        'Pacific/Easter' => 'hora de Chile (Easter)',
+        'Pacific/Chatham' => 'hora de Chatham',
+        'Pacific/Easter' => 'hora del Insula de Pascha',
         'Pacific/Efate' => 'hora de Vanuatu (Efate)',
-        'Pacific/Enderbury' => 'hora de Kiribati (Enderbury)',
+        'Pacific/Enderbury' => 'hora del Insulas Phenice (Enderbury)',
         'Pacific/Fakaofo' => 'hora de Tokelau (Fakaofo)',
-        'Pacific/Fiji' => 'hora de Fiji (Fiji)',
+        'Pacific/Fiji' => 'hora de Fiji',
         'Pacific/Funafuti' => 'hora de Tuvalu (Funafuti)',
-        'Pacific/Galapagos' => 'hora de Ecuador (Galapagos)',
-        'Pacific/Gambier' => 'hora de Polynesia francese (Gambier)',
-        'Pacific/Guadalcanal' => 'hora de Insulas Solomon (Guadalcanal)',
-        'Pacific/Guam' => 'hora de Guam (Guam)',
+        'Pacific/Galapagos' => 'hora del Galápagos',
+        'Pacific/Gambier' => 'hora de Gambier',
+        'Pacific/Guadalcanal' => 'hora del Insulas Solomon (Guadalcanal)',
+        'Pacific/Guam' => 'hora standard de Chamorro (Guam)',
         'Pacific/Honolulu' => 'hora de Hawaii-Aleutianas (Honolulu)',
-        'Pacific/Johnston' => 'hora de Hawaii-Aleutianas (Johnston)',
-        'Pacific/Kiritimati' => 'hora de Kiribati (Kiritimati)',
-        'Pacific/Kosrae' => 'hora de Micronesia (Kosrae)',
-        'Pacific/Kwajalein' => 'hora de Insulas Marshall (Kwajalein)',
-        'Pacific/Majuro' => 'hora de Insulas Marshall (Majuro)',
-        'Pacific/Marquesas' => 'hora de Polynesia francese (Marquesas)',
-        'Pacific/Midway' => 'hora de Insulas peripheric del SUA (Midway)',
-        'Pacific/Nauru' => 'hora de Nauru (Nauru)',
-        'Pacific/Niue' => 'hora de Niue (Niue)',
-        'Pacific/Norfolk' => 'hora de Insula Norfolk (Norfolk)',
+        'Pacific/Kiritimati' => 'hora del Insulas del Linea (Kiritimati)',
+        'Pacific/Kosrae' => 'hora de Kosrae',
+        'Pacific/Kwajalein' => 'hora del Insulas Marshall (Kwajalein)',
+        'Pacific/Majuro' => 'hora del Insulas Marshall (Majuro)',
+        'Pacific/Marquesas' => 'hora de Marquesas',
+        'Pacific/Midway' => 'hora de Samoa (Midway)',
+        'Pacific/Nauru' => 'hora de Nauru',
+        'Pacific/Niue' => 'hora de Niue',
+        'Pacific/Norfolk' => 'hora del Insula Norfolk',
         'Pacific/Noumea' => 'hora de Nove Caledonia (Noumea)',
-        'Pacific/Pago_Pago' => 'hora de Samoa american (Pago Pago)',
-        'Pacific/Palau' => 'hora de Palau (Palau)',
-        'Pacific/Pitcairn' => 'hora de Insulas Pitcairn (Pitcairn)',
-        'Pacific/Ponape' => 'hora de Micronesia (Pohnpei)',
+        'Pacific/Pago_Pago' => 'hora de Samoa (Pago Pago)',
+        'Pacific/Palau' => 'hora de Palau',
+        'Pacific/Pitcairn' => 'hora de Pitcairn',
+        'Pacific/Ponape' => 'hora de Ponape (Pohnpei)',
         'Pacific/Port_Moresby' => 'hora de Papua Nove Guinea (Port Moresby)',
-        'Pacific/Rarotonga' => 'hora de Insulas Cook (Rarotonga)',
-        'Pacific/Saipan' => 'hora de Insulas Marianna del Nord (Saipan)',
-        'Pacific/Tahiti' => 'hora de Polynesia francese (Tahiti)',
-        'Pacific/Tarawa' => 'hora de Kiribati (Tarawa)',
+        'Pacific/Rarotonga' => 'hora del Insulas Cook (Rarotonga)',
+        'Pacific/Saipan' => 'hora standard de Chamorro (Saipan)',
+        'Pacific/Tahiti' => 'hora de Tahiti',
+        'Pacific/Tarawa' => 'hora del Insulas Gilbert (Tarawa)',
         'Pacific/Tongatapu' => 'hora de Tonga (Tongatapu)',
-        'Pacific/Truk' => 'hora de Micronesia (Chuuk)',
-        'Pacific/Wake' => 'hora de Insulas peripheric del SUA (Wake)',
-        'Pacific/Wallis' => 'hora de Wallis e Futuna (Wallis)',
-    ],
-    'Meta' => [
+        'Pacific/Truk' => 'hora de Chuuk',
+        'Pacific/Wake' => 'hora del Insula Wake',
+        'Pacific/Wallis' => 'hora de Wallis e Futuna',
     ],
+    'Meta' => [],
 ];
