@@ -106,7 +106,7 @@ return [
         'America/Fort_Nelson' => 'Rocky-Mountain-Zäit (Fort Nelson)',
         'America/Fortaleza' => 'Brasília-Zäit (Fortaleza)',
         'America/Glace_Bay' => 'Atlantik-Zäit (Glace Bay)',
-        'America/Godthab' => 'Westgrönland-Zäit (Nuuk)',
+        'America/Godthab' => 'Grönland Zäit (Nuuk)',
         'America/Goose_Bay' => 'Atlantik-Zäit (Goose Bay)',
         'America/Grand_Turk' => 'Nordamerikanesch Ostküstenzäit (Grand Turk)',
         'America/Grenada' => 'Atlantik-Zäit (Grenada)',
@@ -156,7 +156,6 @@ return [
         'America/Montserrat' => 'Atlantik-Zäit (Montserrat)',
         'America/Nassau' => 'Nordamerikanesch Ostküstenzäit (Nassau)',
         'America/New_York' => 'Nordamerikanesch Ostküstenzäit (New York)',
-        'America/Nipigon' => 'Nordamerikanesch Ostküstenzäit (Nipigon)',
         'America/Nome' => 'Alaska-Zäit (Nome)',
         'America/Noronha' => 'Fernando-de-Noronha-Zäit',
         'America/North_Dakota/Beulah' => 'Nordamerikanesch Inlandzäit (Beulah, North Dakota)',
@@ -164,7 +163,6 @@ return [
         'America/North_Dakota/New_Salem' => 'Nordamerikanesch Inlandzäit (New Salem, North Dakota)',
         'America/Ojinaga' => 'Nordamerikanesch Inlandzäit (Ojinaga)',
         'America/Panama' => 'Nordamerikanesch Ostküstenzäit (Panama)',
-        'America/Pangnirtung' => 'Nordamerikanesch Ostküstenzäit (Pangnirtung)',
         'America/Paramaribo' => 'Suriname-Zäit (Paramaribo)',
         'America/Phoenix' => 'Rocky-Mountain-Zäit (Phoenix)',
         'America/Port-au-Prince' => 'Nordamerikanesch Ostküstenzäit (Port-au-Prince)',
@@ -172,18 +170,16 @@ return [
         'America/Porto_Velho' => 'Amazonas-Zäit (Porto Velho)',
         'America/Puerto_Rico' => 'Atlantik-Zäit (Puerto Rico)',
         'America/Punta_Arenas' => 'Chilenesch Zäit (Punta Arenas)',
-        'America/Rainy_River' => 'Nordamerikanesch Inlandzäit (Rainy River)',
         'America/Rankin_Inlet' => 'Nordamerikanesch Inlandzäit (Rankin Inlet)',
         'America/Recife' => 'Brasília-Zäit (Recife)',
         'America/Regina' => 'Nordamerikanesch Inlandzäit (Regina)',
         'America/Resolute' => 'Nordamerikanesch Inlandzäit (Resolute)',
         'America/Rio_Branco' => 'Acre-Zäit (Rio Branco)',
-        'America/Santa_Isabel' => 'Nordwest-Mexiko-Zäit (Santa Isabel)',
         'America/Santarem' => 'Brasília-Zäit (Santarem)',
         'America/Santiago' => 'Chilenesch Zäit (Santiago)',
         'America/Santo_Domingo' => 'Atlantik-Zäit (Santo Domingo)',
         'America/Sao_Paulo' => 'Brasília-Zäit (Sao Paulo)',
-        'America/Scoresbysund' => 'Ostgrönland-Zäit (Ittoqqortoormiit)',
+        'America/Scoresbysund' => 'Grönland Zäit (Ittoqqortoormiit)',
         'America/Sitka' => 'Alaska-Zäit (Sitka)',
         'America/St_Barthelemy' => 'Atlantik-Zäit (Saint-Barthélemy)',
         'America/St_Johns' => 'Neifundland-Zäit (St. John’s)',
@@ -194,7 +190,6 @@ return [
         'America/Swift_Current' => 'Nordamerikanesch Inlandzäit (Swift Current)',
         'America/Tegucigalpa' => 'Nordamerikanesch Inlandzäit (Tegucigalpa)',
         'America/Thule' => 'Atlantik-Zäit (Thule)',
-        'America/Thunder_Bay' => 'Nordamerikanesch Ostküstenzäit (Thunder Bay)',
         'America/Tijuana' => 'Nordamerikanesch Westküstenzäit (Tijuana)',
         'America/Toronto' => 'Nordamerikanesch Ostküstenzäit (Toronto)',
         'America/Tortola' => 'Atlantik-Zäit (Tortola)',
@@ -202,8 +197,7 @@ return [
         'America/Whitehorse' => 'Kanada Zäit (Whitehorse)',
         'America/Winnipeg' => 'Nordamerikanesch Inlandzäit (Winnipeg)',
         'America/Yakutat' => 'Alaska-Zäit (Yakutat)',
-        'America/Yellowknife' => 'Rocky-Mountain-Zäit (Yellowknife)',
-        'Antarctica/Casey' => 'Antarktis Zäit (Casey)',
+        'Antarctica/Casey' => 'Westaustralesch Zäit (Casey)',
         'Antarctica/Davis' => 'Davis-Zäit',
         'Antarctica/DumontDUrville' => 'Dumont-d’Urville-Zäit',
         'Antarctica/Macquarie' => 'Ostaustralesch Zäit (Macquarie)',
@@ -216,7 +210,7 @@ return [
         'Antarctica/Vostok' => 'Wostok-Zäit',
         'Arctic/Longyearbyen' => 'Mëtteleuropäesch Zäit (Longyearbyen)',
         'Asia/Aden' => 'Arabesch Zäit (Aden)',
-        'Asia/Almaty' => 'Ostkasachesch Zäit (Almaty)',
+        'Asia/Almaty' => 'Westkasachesch Zäit (Almaty)',
         'Asia/Amman' => 'Osteuropäesch Zäit (Amman)',
         'Asia/Anadyr' => 'Anadyr-Zäit',
         'Asia/Aqtau' => 'Westkasachesch Zäit (Aqtau)',
@@ -272,7 +266,7 @@ return [
         'Asia/Pontianak' => 'Westindonesesch Zäit (Pontianak)',
         'Asia/Pyongyang' => 'Koreanesch Zäit (Pjöngjang)',
         'Asia/Qatar' => 'Arabesch Zäit (Katar)',
-        'Asia/Qostanay' => 'Ostkasachesch Zäit (Qostanay)',
+        'Asia/Qostanay' => 'Westkasachesch Zäit (Qostanay)',
         'Asia/Qyzylorda' => 'Westkasachesch Zäit (Qyzylorda)',
         'Asia/Rangoon' => 'Myanmar-Zäit (Yangon)',
         'Asia/Riyadh' => 'Arabesch Zäit (Riad)',
@@ -311,7 +305,6 @@ return [
         'Australia/Adelaide' => 'Zentralaustralesch Zäit (Adelaide)',
         'Australia/Brisbane' => 'Ostaustralesch Zäit (Brisbane)',
         'Australia/Broken_Hill' => 'Zentralaustralesch Zäit (Broken Hill)',
-        'Australia/Currie' => 'Ostaustralesch Zäit (Currie)',
         'Australia/Darwin' => 'Zentralaustralesch Zäit (Darwin)',
         'Australia/Eucla' => 'Zentral-/Westaustralesch Zäit (Eucla)',
         'Australia/Hobart' => 'Ostaustralesch Zäit (Hobart)',
@@ -373,7 +366,6 @@ return [
         'Europe/Tallinn' => 'Osteuropäesch Zäit (Tallinn)',
         'Europe/Tirane' => 'Mëtteleuropäesch Zäit (Tirana)',
         'Europe/Ulyanovsk' => 'Moskauer Zäit (Ulyanovsk)',
-        'Europe/Uzhgorod' => 'Osteuropäesch Zäit (Uschgorod)',
         'Europe/Vaduz' => 'Mëtteleuropäesch Zäit (Vaduz)',
         'Europe/Vatican' => 'Mëtteleuropäesch Zäit (Vatikan)',
         'Europe/Vienna' => 'Mëtteleuropäesch Zäit (Wien)',
@@ -381,7 +373,6 @@ return [
         'Europe/Volgograd' => 'Wolgograd-Zäit',
         'Europe/Warsaw' => 'Mëtteleuropäesch Zäit (Warschau)',
         'Europe/Zagreb' => 'Mëtteleuropäesch Zäit (Zagreb)',
-        'Europe/Zaporozhye' => 'Osteuropäesch Zäit (Saporischschja)',
         'Europe/Zurich' => 'Mëtteleuropäesch Zäit (Zürech)',
         'Indian/Antananarivo' => 'Ostafrikanesch Zäit (Antananarivo)',
         'Indian/Chagos' => 'Indeschen Ozean-Zäit (Chagos)',
@@ -411,7 +402,6 @@ return [
         'Pacific/Guadalcanal' => 'Salomoninselen-Zäit (Guadalcanal)',
         'Pacific/Guam' => 'Chamorro-Zäit (Guam)',
         'Pacific/Honolulu' => 'Hawaii-Aleuten-Zäit (Honolulu)',
-        'Pacific/Johnston' => 'Hawaii-Aleuten-Zäit (Johnston)',
         'Pacific/Kiritimati' => 'Linneninselen-Zäit (Kiritimati)',
         'Pacific/Kosrae' => 'Kosrae-Zäit',
         'Pacific/Kwajalein' => 'Marshallinselen-Zäit (Kwajalein)',
@@ -436,6 +426,5 @@ return [
         'Pacific/Wake' => 'Wake-Insel-Zäit',
         'Pacific/Wallis' => 'Wallis-a-Futuna-Zäit',
     ],
-    'Meta' => [
-    ],
+    'Meta' => [],
 ];
