@@ -106,7 +106,7 @@ return [
         'America/Fort_Nelson' => 'ເວລາແຖບພູເຂົາ (ຟອດ ເນວສັນ)',
         'America/Fortaleza' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ຟໍຕາເລຊາ)',
         'America/Glace_Bay' => 'ເວລາຂອງອາແລນຕິກ (ເກລດເບ)',
-        'America/Godthab' => 'ເວລາກຣີນແລນຕາເວັນຕົກ (ນູກ)',
+        'America/Godthab' => 'ເວລາ ກຣີນແລນ (ນູກ)',
         'America/Goose_Bay' => 'ເວລາຂອງອາແລນຕິກ (ກູສເບ)',
         'America/Grand_Turk' => 'ເວລາຕາເວັນອອກ (ແກຣນ ເທີກ)',
         'America/Grenada' => 'ເວລາຂອງອາແລນຕິກ (ເກຣນາດາ)',
@@ -156,7 +156,6 @@ return [
         'America/Montserrat' => 'ເວລາຂອງອາແລນຕິກ (ມອນເຊີຣັດ)',
         'America/Nassau' => 'ເວລາຕາເວັນອອກ (ແນສຊໍ)',
         'America/New_York' => 'ເວລາຕາເວັນອອກ (ນິວຢອກ)',
-        'America/Nipigon' => 'ເວລາຕາເວັນອອກ (ນີປີກອນ)',
         'America/Nome' => 'ເວລາອະລັສກາ (ນອມ)',
         'America/Noronha' => 'ເວລາເຟນັນໂດເດໂນຮອນຮາ (ນໍຣອນຮາ)',
         'America/North_Dakota/Beulah' => 'ເວລາກາງ (ເບີລາ, ນອດ ດາໂກຕາ)',
@@ -164,7 +163,6 @@ return [
         'America/North_Dakota/New_Salem' => 'ເວລາກາງ (ນິວ ຊາເລມ, ນອດ ດາໂກຕາ)',
         'America/Ojinaga' => 'ເວລາກາງ (ໂອຈິນາກາ)',
         'America/Panama' => 'ເວລາຕາເວັນອອກ (ພານາມາ)',
-        'America/Pangnirtung' => 'ເວລາຕາເວັນອອກ (ແພງເນີດທັງ)',
         'America/Paramaribo' => 'ເວ​ລາ​ຊຸ​ຣິ​ນາມ (ພາຣາມາຣິໂບ)',
         'America/Phoenix' => 'ເວລາແຖບພູເຂົາ (ຟິນິກ)',
         'America/Port-au-Prince' => 'ເວລາຕາເວັນອອກ (ປໍໂຕແປຣງ)',
@@ -172,18 +170,16 @@ return [
         'America/Porto_Velho' => 'ເວລາຕາມເຂດອາເມຊອນ (ປໍຕູ ເວວຢູ)',
         'America/Puerto_Rico' => 'ເວລາຂອງອາແລນຕິກ (ເປີໂທຣິໂກ)',
         'America/Punta_Arenas' => 'ເວ​ລາ​ຊິ​ລີ (ພຸນທາ ອະຣີນາສ໌)',
-        'America/Rainy_River' => 'ເວລາກາງ (ເຣນນີ ຣິເວີ)',
         'America/Rankin_Inlet' => 'ເວລາກາງ (ແຣນກິນ ອິນເລັດ)',
         'America/Recife' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ເຣຊິເຟ)',
         'America/Regina' => 'ເວລາກາງ (ເຣຈິນາ)',
         'America/Resolute' => 'ເວລາກາງ (ເຣໂຊລຸດ)',
         'America/Rio_Branco' => 'ເວລາຂອງອາເກຣ (ຣິໂອ ບຣັນໂກ)',
-        'America/Santa_Isabel' => '​ເວ​ລາ​ນອດ​ເວ​ສ​ເມັກ​ຊິ​ໂກ (ຊານຕາ ອິດຊາເບວ)',
         'America/Santarem' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ຊັນຕາເຣມ)',
         'America/Santiago' => 'ເວ​ລາ​ຊິ​ລີ (ຊັນຕີອາໂກ)',
         'America/Santo_Domingo' => 'ເວລາຂອງອາແລນຕິກ (ຊານໂຕໂດມິນໂກ)',
         'America/Sao_Paulo' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ເຊົາ ເປົາໂລ)',
-        'America/Scoresbysund' => 'ເວລາຕາເວັນອອກຂອງກຣີນແລນ (ອິໂຕຄໍທົວມິດ)',
+        'America/Scoresbysund' => 'ເວລາ ກຣີນແລນ (ອິໂຕຄໍທົວມິດ)',
         'America/Sitka' => 'ເວລາອະລັສກາ (ຊິດກາ)',
         'America/St_Barthelemy' => 'ເວລາຂອງອາແລນຕິກ (ເຊນບາເທເລມີ)',
         'America/St_Johns' => 'ເວ​ລາ​ນິວ​ຟາວ​ແລນ (ເຊນ ຈອນ)',
@@ -194,7 +190,6 @@ return [
         'America/Swift_Current' => 'ເວລາກາງ (ສະວິຟ ເຄີເຣນ)',
         'America/Tegucigalpa' => 'ເວລາກາງ (ເຕກູຊີການປາ)',
         'America/Thule' => 'ເວລາຂອງອາແລນຕິກ (ທູເລ)',
-        'America/Thunder_Bay' => 'ເວລາຕາເວັນອອກ (ທັນເດີເບ)',
         'America/Tijuana' => 'ເວລາແປຊິຟິກ (ທີຈົວນາ)',
         'America/Toronto' => 'ເວລາຕາເວັນອອກ (ໂທຣອນໂຕ)',
         'America/Tortola' => 'ເວລາຂອງອາແລນຕິກ (ທໍໂຕລາ)',
@@ -202,8 +197,7 @@ return [
         'America/Whitehorse' => 'ເວລາຢູຄອນ (ໄວທ໌ຮອສ)',
         'America/Winnipeg' => 'ເວລາກາງ (ວິນນີເພກ)',
         'America/Yakutat' => 'ເວລາອະລັສກາ (ຢາຄູຕັດ)',
-        'America/Yellowknife' => 'ເວລາແຖບພູເຂົາ (ເຢໂລໄນຟ໌)',
-        'Antarctica/Casey' => 'ເວລາເຄຊີ',
+        'Antarctica/Casey' => 'ເວ​ລາ​ອອສ​ເຕຣ​ເລຍ​ຕາ​ເວັນ​ຕົກ (ເຄຊີ)',
         'Antarctica/Davis' => 'ເວລາເດວິດ (ດາວີສ)',
         'Antarctica/DumontDUrville' => 'ເວລາດູມອງດູວິລ (ດູມອນດີຍູວີວສ໌)',
         'Antarctica/Macquarie' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ແມັກຄົວຣີ)',
@@ -216,7 +210,7 @@ return [
         'Antarctica/Vostok' => 'ເວລາ ວອສໂຕກ (ວໍສະຕອກ)',
         'Arctic/Longyearbyen' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ລອງເຢຍບຽນ)',
         'Asia/Aden' => 'ເວ​ລາ​ອາ​ຣາ​ບຽນ (ເອເດັນ)',
-        'Asia/Almaty' => 'ເວ​ລາ​ຄາ​ຊັກ​ສ​ຖານ​ຕາ​ເວັນ​ອອກ (ອໍມາຕີ)',
+        'Asia/Almaty' => 'ເວ​ລາ​ຄາ​ຊັກ​ສ​ຖານ​ຕາ​ເວັນ​ຕົກ (ອໍມາຕີ)',
         'Asia/Amman' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ອຳມານ)',
         'Asia/Anadyr' => 'ເວລາ ຣັດເຊຍ (ອານາດີ)',
         'Asia/Aqtau' => 'ເວ​ລາ​ຄາ​ຊັກ​ສ​ຖານ​ຕາ​ເວັນ​ຕົກ (ອັດຕາອູ)',
@@ -272,7 +266,7 @@ return [
         'Asia/Pontianak' => 'ເວ​ລາ​ອິນ​ໂດ​ເນ​ເຊຍ​ຕາ​ເວັນ​ຕົກ (ພອນເທຍນັກ)',
         'Asia/Pyongyang' => 'ເວລາເກົາຫຼີ (ປຽງຢາງ)',
         'Asia/Qatar' => 'ເວ​ລາ​ອາ​ຣາ​ບຽນ (ກາຕາຣ໌)',
-        'Asia/Qostanay' => 'ເວ​ລາ​ຄາ​ຊັກ​ສ​ຖານ​ຕາ​ເວັນ​ອອກ (ຄອສຕາເນ)',
+        'Asia/Qostanay' => 'ເວ​ລາ​ຄາ​ຊັກ​ສ​ຖານ​ຕາ​ເວັນ​ຕົກ (ຄອສຕາເນ)',
         'Asia/Qyzylorda' => 'ເວ​ລາ​ຄາ​ຊັກ​ສ​ຖານ​ຕາ​ເວັນ​ຕົກ (ໄຄຊີລໍດາ)',
         'Asia/Rangoon' => 'ເວລາມຽນມາ (ຢາງກອນ)',
         'Asia/Riyadh' => 'ເວ​ລາ​ອາ​ຣາ​ບຽນ (ຣີຢາດ)',
@@ -311,7 +305,6 @@ return [
         'Australia/Adelaide' => 'ເວ​ລາອອ​ສ​ເຕຣ​ເລຍ​ກາງ (ເອດີແລດ)',
         'Australia/Brisbane' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ບຣິສເບນ)',
         'Australia/Broken_Hill' => 'ເວ​ລາອອ​ສ​ເຕຣ​ເລຍ​ກາງ (ໂບຣກເຄນ ຮິວ)',
-        'Australia/Currie' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ກູຣີ)',
         'Australia/Darwin' => 'ເວ​ລາອອ​ສ​ເຕຣ​ເລຍ​ກາງ (ດາວິນ)',
         'Australia/Eucla' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ກາງ​ຕາ​ເວັນ​ຕົກ (ຢູຄລາ)',
         'Australia/Hobart' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ໂຮບາດ)',
@@ -374,7 +367,6 @@ return [
         'Europe/Tallinn' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ທາລລິນນ໌)',
         'Europe/Tirane' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ທິຣານ)',
         'Europe/Ulyanovsk' => 'ເວ​ລາ​ມອ​ສ​ໂຄ (ອູລີອານອບສຄ໌)',
-        'Europe/Uzhgorod' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ອັສຊ໌ກໍໂຣດ)',
         'Europe/Vaduz' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ວາດາຊ)',
         'Europe/Vatican' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ວາຕິກັນ)',
         'Europe/Vienna' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ວຽນນາ)',
@@ -382,7 +374,6 @@ return [
         'Europe/Volgograd' => 'ເວລາໂວໂກກຣາດ (ວອລໂກກຣາດ)',
         'Europe/Warsaw' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ວໍຊໍ)',
         'Europe/Zagreb' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ຊາເກຣບ)',
-        'Europe/Zaporozhye' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ຊາໂປໂຣຊີ)',
         'Europe/Zurich' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ຊູຣິກ)',
         'Indian/Antananarivo' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ອັນຕານານາຣິໂວ)',
         'Indian/Chagos' => 'ເວລາຫມະຫາສະຫມຸດອິນເດຍ (ຊາໂກສ)',
@@ -412,7 +403,6 @@ return [
         'Pacific/Guadalcanal' => 'ເວລາຫມູ່ເກາະໂຊໂລມອນ (ກົວດັລຄະແນລ)',
         'Pacific/Guam' => 'ເວ​ລາ​ຈາ​ໂມ​ໂຣ (ກວມ)',
         'Pacific/Honolulu' => 'ເວລາຮາວາຍ-ເອລູທຽນ (ໂຮໂນລູລູ)',
-        'Pacific/Johnston' => 'ເວລາຮາວາຍ-ເອລູທຽນ (ຈອນສະໂຕນ)',
         'Pacific/Kiritimati' => 'ເວ​ລາ​ໝູ່​ເກາະ​ລາຍ (ຄີຣິທີມາຕີ)',
         'Pacific/Kosrae' => 'ເວລາຄອສແຣ (ຄໍສແຣ)',
         'Pacific/Kwajalein' => 'ເວ​ລາ​ໝູ່​ເກາະ​ມາ​ແຊວ (ຄວາຈາເລນ)',
@@ -437,6 +427,5 @@ return [
         'Pacific/Wake' => 'ເວລາເກາະເວກ',
         'Pacific/Wallis' => 'ເວລາວາລລິສ ແລະ ຟູຕູນາ (ວາລິດ)',
     ],
-    'Meta' => [
-    ],
+    'Meta' => [],
 ];
