@@ -106,7 +106,7 @@ return [
         'America/Fort_Nelson' => 'पर्वतीय वेळ (फोर्ट नेल्सन)',
         'America/Fortaleza' => 'ब्राझिलिया वेळ (फोर्टालेझा)',
         'America/Glace_Bay' => 'अटलांटिक वेळ (ग्लेस उपसागर)',
-        'America/Godthab' => 'पश्चिम ग्रीनलँड वेळ (नूक)',
+        'America/Godthab' => 'ग्रीनलंड वेळ (नूक)',
         'America/Goose_Bay' => 'अटलांटिक वेळ (गूस उपसागर)',
         'America/Grand_Turk' => 'पौर्वात्य वेळ (ग्रँड टर्क)',
         'America/Grenada' => 'अटलांटिक वेळ (ग्रेनेडा)',
@@ -156,7 +156,6 @@ return [
         'America/Montserrat' => 'अटलांटिक वेळ (माँन्टसेरात)',
         'America/Nassau' => 'पौर्वात्य वेळ (नसाऊ)',
         'America/New_York' => 'पौर्वात्य वेळ (न्यूयॉर्क)',
-        'America/Nipigon' => 'पौर्वात्य वेळ (निपिगोन)',
         'America/Nome' => 'अलास्का वेळ (नोम)',
         'America/Noronha' => 'फर्नांडो दी नोरोन्हा वेळ',
         'America/North_Dakota/Beulah' => 'केंद्रीय वेळ (ब्युलाह, उत्तर डकोटा)',
@@ -164,7 +163,6 @@ return [
         'America/North_Dakota/New_Salem' => 'केंद्रीय वेळ (न्यू सालेम, उत्तर डकोटा)',
         'America/Ojinaga' => 'केंद्रीय वेळ (ओजिनागा)',
         'America/Panama' => 'पौर्वात्य वेळ (पनामा)',
-        'America/Pangnirtung' => 'पौर्वात्य वेळ (पँगनिरतुंग)',
         'America/Paramaribo' => 'सुरिनाम वेळ (पारमरीबो)',
         'America/Phoenix' => 'पर्वतीय वेळ (फॉनिक्स)',
         'America/Port-au-Prince' => 'पौर्वात्य वेळ (पोर्ट-औ-प्रिंस)',
@@ -172,18 +170,16 @@ return [
         'America/Porto_Velho' => 'अ‍ॅमेझॉन वेळ (पोर्टो वेल्हो)',
         'America/Puerto_Rico' => 'अटलांटिक वेळ (प्युएर्तो रिको)',
         'America/Punta_Arenas' => 'चिली वेळ (पुंता अरीनास)',
-        'America/Rainy_River' => 'केंद्रीय वेळ (रेनी नदी)',
         'America/Rankin_Inlet' => 'केंद्रीय वेळ (रॅनकिन इनलेट)',
         'America/Recife' => 'ब्राझिलिया वेळ (रेसिफे)',
         'America/Regina' => 'केंद्रीय वेळ (रेजिना)',
         'America/Resolute' => 'केंद्रीय वेळ (रेजोल्यूट)',
         'America/Rio_Branco' => 'एकर वेळ (रियो ब्रांको)',
-        'America/Santa_Isabel' => 'वायव्य मेक्सिको वेळ (सांता इसाबेल)',
         'America/Santarem' => 'ब्राझिलिया वेळ (सँटारेम)',
         'America/Santiago' => 'चिली वेळ (सॅन्टिएगो)',
         'America/Santo_Domingo' => 'अटलांटिक वेळ (सॅन्टो डोमिंगो)',
         'America/Sao_Paulo' => 'ब्राझिलिया वेळ (साओ पावलो)',
-        'America/Scoresbysund' => 'पूर्व ग्रीनलँड वेळ (इटोकॉरटॉर्मीट)',
+        'America/Scoresbysund' => 'ग्रीनलंड वेळ (इटोकॉरटॉर्मीट)',
         'America/Sitka' => 'अलास्का वेळ (सिटका)',
         'America/St_Barthelemy' => 'अटलांटिक वेळ (सेंट बार्थेलेमी)',
         'America/St_Johns' => 'न्यू फाउंडलंड वेळ (सेंट जॉन्स)',
@@ -194,7 +190,6 @@ return [
         'America/Swift_Current' => 'केंद्रीय वेळ (स्विफ्ट करंट)',
         'America/Tegucigalpa' => 'केंद्रीय वेळ (टेगुसिगाल्पा)',
         'America/Thule' => 'अटलांटिक वेळ (थुले)',
-        'America/Thunder_Bay' => 'पौर्वात्य वेळ (थंडर उपसागर)',
         'America/Tijuana' => 'पॅसिफिक वेळ (तिजुआना)',
         'America/Toronto' => 'पौर्वात्य वेळ (टोरोंटो)',
         'America/Tortola' => 'अटलांटिक वेळ (टोर्टोला)',
@@ -202,8 +197,7 @@ return [
         'America/Whitehorse' => 'युकोन वेळ (व्हाइटहॉर्स)',
         'America/Winnipeg' => 'केंद्रीय वेळ (विनीपेग)',
         'America/Yakutat' => 'अलास्का वेळ (यकुतात)',
-        'America/Yellowknife' => 'पर्वतीय वेळ (यलोनाइफ)',
-        'Antarctica/Casey' => 'अंटार्क्टिका वेळ (कॅसे)',
+        'Antarctica/Casey' => 'पश्चिम ऑस्ट्रेलिया वेळ (कॅसे)',
         'Antarctica/Davis' => 'डेव्हिस वेळ',
         'Antarctica/DumontDUrville' => 'ड्युमॉन्ट-ड्युर्विल वेळ',
         'Antarctica/Macquarie' => 'पूर्व ऑस्ट्रेलिया वेळ (मॅक्वायर)',
@@ -216,7 +210,7 @@ return [
         'Antarctica/Vostok' => 'व्होस्टॉक वेळ (वोस्टोक)',
         'Arctic/Longyearbyen' => 'मध्‍य युरोपियन वेळ (लाँगइयरबीयेन)',
         'Asia/Aden' => 'अरेबियन वेळ (एडेन)',
-        'Asia/Almaty' => 'पूर्व कझाकस्तान वेळ (अल्माटी)',
+        'Asia/Almaty' => 'पश्चिम कझाकस्तान वेळ (अल्माटी)',
         'Asia/Amman' => 'पूर्व युरोपियन वेळ (अम्मान)',
         'Asia/Anadyr' => 'एनाडीयर वेळ',
         'Asia/Aqtau' => 'पश्चिम कझाकस्तान वेळ (अ‍ॅक्टौ)',
@@ -272,7 +266,7 @@ return [
         'Asia/Pontianak' => 'पश्चिमी इंडोनेशिया वेळ (पाँटियानाक)',
         'Asia/Pyongyang' => 'कोरियन वेळ (प्योंगयांग)',
         'Asia/Qatar' => 'अरेबियन वेळ (कतार)',
-        'Asia/Qostanay' => 'पूर्व कझाकस्तान वेळ (कोस्टाने)',
+        'Asia/Qostanay' => 'पश्चिम कझाकस्तान वेळ (कोस्टाने)',
         'Asia/Qyzylorda' => 'पश्चिम कझाकस्तान वेळ (किझीलोर्डा)',
         'Asia/Rangoon' => 'म्यानमार वेळ (रंगून)',
         'Asia/Riyadh' => 'अरेबियन वेळ (रियाध)',
@@ -311,7 +305,6 @@ return [
         'Australia/Adelaide' => 'मध्य ऑस्ट्रेलिया वेळ (एडलेड)',
         'Australia/Brisbane' => 'पूर्व ऑस्ट्रेलिया वेळ (ब्रिस्बेन)',
         'Australia/Broken_Hill' => 'मध्य ऑस्ट्रेलिया वेळ (ब्रोकन हिल)',
-        'Australia/Currie' => 'पूर्व ऑस्ट्रेलिया वेळ (कुह्री)',
         'Australia/Darwin' => 'मध्य ऑस्ट्रेलिया वेळ (डार्विन)',
         'Australia/Eucla' => 'ऑस्ट्रेलियन मध्य-पश्चिम वेळ (उक्ला)',
         'Australia/Hobart' => 'पूर्व ऑस्ट्रेलिया वेळ (होबार्ट)',
@@ -374,7 +367,6 @@ return [
         'Europe/Tallinn' => 'पूर्व युरोपियन वेळ (तालिन)',
         'Europe/Tirane' => 'मध्‍य युरोपियन वेळ (टिराने)',
         'Europe/Ulyanovsk' => 'मॉस्को वेळ (उल्यानोव्स्क)',
-        'Europe/Uzhgorod' => 'पूर्व युरोपियन वेळ (उझहोरोड)',
         'Europe/Vaduz' => 'मध्‍य युरोपियन वेळ (वडूझ)',
         'Europe/Vatican' => 'मध्‍य युरोपियन वेळ (व्हॅटिकन)',
         'Europe/Vienna' => 'मध्‍य युरोपियन वेळ (व्हिएन्ना)',
@@ -382,7 +374,6 @@ return [
         'Europe/Volgograd' => 'व्होल्गोग्राड वेळ',
         'Europe/Warsaw' => 'मध्‍य युरोपियन वेळ (वॉर्सा)',
         'Europe/Zagreb' => 'मध्‍य युरोपियन वेळ (झॅग्रेब)',
-        'Europe/Zaporozhye' => 'पूर्व युरोपियन वेळ (झापोरोझे)',
         'Europe/Zurich' => 'मध्‍य युरोपियन वेळ (झुरिक)',
         'Indian/Antananarivo' => 'पूर्व आफ्रिका वेळ (अंटानानारिवो)',
         'Indian/Chagos' => 'हिंदमहासागर वेळ (चागोस)',
@@ -412,7 +403,6 @@ return [
         'Pacific/Guadalcanal' => 'सोलोमॉन बेटे वेळ (ग्वाडलकनाल)',
         'Pacific/Guam' => 'चामोरो प्रमाण वेळ (गुआम)',
         'Pacific/Honolulu' => 'हवाई-अलूशन वेळ (होनोलुलू)',
-        'Pacific/Johnston' => 'हवाई-अलूशन वेळ (जोहान्स्टन)',
         'Pacific/Kiritimati' => 'लाइन बेटे वेळ (किरितिमाती)',
         'Pacific/Kosrae' => 'कोस्राई वेळ (कोशाय)',
         'Pacific/Kwajalein' => 'मार्शल बेटे वेळ (क्वाजालेईन)',
