@@ -106,7 +106,7 @@ return [
         'America/Fort_Nelson' => 'మౌంటెయిన్ సమయం (ఫోర్ట్ నెల్సన్)',
         'America/Fortaleza' => 'బ్రెజిలియా సమయం (ఫోర్టలేజా)',
         'America/Glace_Bay' => 'అట్లాంటిక్ సమయం (గ్లేస్ బే)',
-        'America/Godthab' => 'పశ్చిమ గ్రీన్‌ల్యాండ్ సమయం (నూక్)',
+        'America/Godthab' => 'గ్రీన్‌ల్యాండ్ సమయం (నూక్)',
         'America/Goose_Bay' => 'అట్లాంటిక్ సమయం (గూస్ బే)',
         'America/Grand_Turk' => 'తూర్పు సమయం (గ్రాండ్ టర్క్)',
         'America/Grenada' => 'అట్లాంటిక్ సమయం (గ్రెనడా)',
@@ -179,7 +179,7 @@ return [
         'America/Santiago' => 'చిలీ సమయం (శాంటియాగో)',
         'America/Santo_Domingo' => 'అట్లాంటిక్ సమయం (శాంటో డోమింగో)',
         'America/Sao_Paulo' => 'బ్రెజిలియా సమయం (సావో పాలో)',
-        'America/Scoresbysund' => 'తూర్పు గ్రీన్‌ల్యాండ్ సమయం (ఇటోక్కోర్టూర్మిట్)',
+        'America/Scoresbysund' => 'గ్రీన్‌ల్యాండ్ సమయం (ఇటోక్కోర్టూర్మిట్)',
         'America/Sitka' => 'అలాస్కా సమయం (సిట్కా)',
         'America/St_Barthelemy' => 'అట్లాంటిక్ సమయం (సెయింట్ బర్తెలెమీ)',
         'America/St_Johns' => 'న్యూఫౌండ్‌ల్యాండ్ సమయం (సెయింట్ జాన్స్)',
@@ -197,7 +197,7 @@ return [
         'America/Whitehorse' => 'యుకోన్ సమయం (వైట్‌హార్స్)',
         'America/Winnipeg' => 'మధ్యమ సమయం (విన్నిపెగ్)',
         'America/Yakutat' => 'అలాస్కా సమయం (యకుటాట్)',
-        'Antarctica/Casey' => 'అంటార్కిటికా సమయం (కేసీ)',
+        'Antarctica/Casey' => 'పశ్చిమ ఆస్ట్రేలియా సమయం (కేసీ)',
         'Antarctica/Davis' => 'డేవిస్ సమయం (డెవిస్)',
         'Antarctica/DumontDUrville' => 'డ్యూమాంట్-డి’ఉర్విల్లే సమయం',
         'Antarctica/Macquarie' => 'తూర్పు ఆస్ట్రేలియా సమయం (మకారీ)',
@@ -210,7 +210,7 @@ return [
         'Antarctica/Vostok' => 'వోస్టోక్ సమయం',
         'Arctic/Longyearbyen' => 'సెంట్రల్ యూరోపియన్ సమయం (లాంగ్‌యియర్‌బైయన్)',
         'Asia/Aden' => 'అరేబియన్ సమయం (ఎడెన్)',
-        'Asia/Almaty' => 'తూర్పు కజకి‌స్తాన్ సమయం (ఆల్మాటి)',
+        'Asia/Almaty' => 'పశ్చిమ కజకిస్తాన్ సమయం (ఆల్మాటి)',
         'Asia/Amman' => 'తూర్పు యూరోపియన్ సమయం (అమ్మన్)',
         'Asia/Anadyr' => 'అనడైర్ సమయం',
         'Asia/Aqtau' => 'పశ్చిమ కజకిస్తాన్ సమయం (అక్టావ్)',
@@ -266,7 +266,7 @@ return [
         'Asia/Pontianak' => 'పశ్చిమ ఇండోనేషియా సమయం (పొన్టియనాక్)',
         'Asia/Pyongyang' => 'కొరియన్ సమయం (ప్యోంగాంగ్)',
         'Asia/Qatar' => 'అరేబియన్ సమయం (ఖతార్)',
-        'Asia/Qostanay' => 'తూర్పు కజకి‌స్తాన్ సమయం (కోస్తానే)',
+        'Asia/Qostanay' => 'పశ్చిమ కజకిస్తాన్ సమయం (కోస్తానే)',
         'Asia/Qyzylorda' => 'పశ్చిమ కజకిస్తాన్ సమయం (క్విజిలోర్డా)',
         'Asia/Rangoon' => 'మయన్మార్ సమయం (యాంగన్)',
         'Asia/Riyadh' => 'అరేబియన్ సమయం (రియాధ్)',
